pyramid_fullauth
================

.. image:: https://travis-ci.org/fizyk/pyramid_fullauth.png?branch=master
    :target: https://travis-ci.org/fizyk/pyramid_fullauth
    :alt: Tests for RandomWords

.. image:: https://coveralls.io/repos/fizyk/pyramid_fullauth/badge.png?branch=master
    :target: https://coveralls.io/r/fizyk/pyramid_fullauth?branch=master
    :alt: Coverage Status

.. image:: https://pypip.in/v/pyramid_fullauth/badge.png
    :target: https://crate.io/packages/pyramid_fullauth/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pyramid_fullauth/badge.png
    :target: https://crate.io/packages/pyramid_fullauth/
    :alt: Number of PyPI downloads

Pyramid fullauth's goal is to provide full plug-in registration functionality for pyramid, with user managing

Instalation:
============

``pip install pyramid_fullauth``

or add **pyramid_fullauth** to your **setup.py** requirements.


Tests:
======

You'll need: packages defined in extra_requires[tests] to run tests, and then:

``py.test``

For detailed test report run this command:

``py.test --cov-report term-missing --cov pyramid_fullauth tests/``
